📘 This documentation is also available in [English](README.md)

---

## 📋 Содержание
- [Обзор](#обзор)
- [Как это работает](#как-это-работает)
  - [Приоритеты данных](#приоритеты-данных)
  - [Структура файлов](#структура-файлов)
- [Для пользователей](#для-пользователей)
  - [Создание пользовательских переопределений](#создание-пользовательских-переопределений)
  - [Пример](#пример)
- [Для разработчиков](#для-разработчиков)
  - [Добавление встроенных переопределений](#добавление-встроенных-переопределений)

---

## 📖 Обзор

В `PortProtonQT` можно изменить:

- Название игры
- Описание
- Обложку

Типы переопределений:

| Тип            | Расположение                                      | Приоритет |
|----------------|---------------------------------------------------|-----------|
| Пользовательские | `~/.local/share/PortProtonQT/custom_data/`        | Высший    |
| Встроенные      | `portprotonqt/custom_data/`                       | Ниже      |

---

## ⚙️ Как это работает

### Приоритеты данных

Данные берутся в следующем порядке:

1. **Пользовательские переопределения**
2. **Встроенные переопределения**
3. **Данные Steam**
4. **Информация из `.desktop` файла**

### Структура файлов

В каждой папке `<имя_exe>` могут быть следующие файлы:

- `metadata.txt` — имя и описание в формате:
  ```txt
  name=Моё название игры
  description=Описание моей игры
  ```
- `cover.<расширение>` — обложка (`.png`, `.jpg`, `.jpeg`, `.bmp`)

---

## 👤 Для пользователей

### Создание пользовательских переопределений

1. **Создайте папку для игры**:
   ```bash
   mkdir -p ~/.local/share/PortProtonQT/custom_data/mygame
   ```

2. **Добавьте переопределения**:
   - **Файл метаданных**:
     ```bash
     echo -e "name=Моя игра\ndescription=Захватывающая игра" > ~/.local/share/PortProtonQT/custom_data/mygame/metadata.txt
     ```
   - **Обложку**:
     ```bash
     cp ~/Images/custom_cover.png ~/.local/share/PortProtonQT/custom_data/mygame/cover.png
     ```

3. **Перезапустите PortProtonQT**.

## 🛠 Для разработчиков

### Добавление встроенных переопределений

1. **Создайте папку в проекте**:
   ```bash
   mkdir -p portprotonqt/custom_data/mygame
   ```

2. **Добавьте файлы**:

- `metadata.txt`:
  ```txt
  name=Стандартное название
  description=Стандартное описание игры
  ```

- Обложка (`cover.png`, например):
  ```bash
  cp path/to/cover.png portprotonqt/custom_data/mygame/cover.png
  ```

3. **Добавьте изменения в репозиторий**:
   ```bash
   git add portprotonqt/custom_data/mygame
   git commit -m "Добавлены встроенные переопределения для mygame"
   ```

---

> Готово! Теперь ваши игры будут выглядеть именно так, как вы хотите 🎮✨
